@@ -1,7 +1,7 @@
-from What.regex_identifier import RegexIdentifier
-from What.languageDetector import LanguageDetector
-from What.magic_numbers import FileSignatures
-from What.nameThatHash import Nth
+from PyWhat.regex_identifier import RegexIdentifier
+from PyWhat.languageDetector import LanguageDetector
+from PyWhat.magic_numbers import FileSignatures
+from PyWhat.nameThatHash import Nth
 import os.path
 
 
@@ -30,9 +30,6 @@ class Identifier:
         identify_obj["Regexes"] = self.regex_id.check(text)
         # get_hashes takes a list of hashes, we split to give it a list
         identify_obj["Hashes"] = self.name_that_hash.get_hashes(text.split())
-        print("\n")
-        print(identify_obj["Hashes"])
-        print("\n")
 
         return identify_obj
 
